@@ -10,7 +10,7 @@ $client->do_one_loop while 1;
 
 =head1 NAME
 
-/tatoeba/000-basic.pl - Bare minimum example BitTorrent client
+000-basic.pl - Bare minimum example BitTorrent client
 
 =head1 Description
 
@@ -23,6 +23,8 @@ C<Net::BitTorrent>-based client.
 
 =head1 Lowdown
 
+This section only makes sense when you view the source.
+
 =over
 
 =item Line 5
@@ -53,7 +55,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008-2009 by Sanko Robinson <sanko@cpan.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -69,6 +71,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: 000-basic.pl 46 2008-12-30 23:25:17Z sanko@cpan.org $
+=for svn $Id: 000-basic.pl d3c97de 2009-09-12 04:31:46Z sanko@cpan.org $
 
 =cut
